#[derive(IterState)]Expand description
A derive macro that automatically derives the IterState trait.
When using this macro to implement the trait, the associated types Value and Solution will both be set to Self, the init_from_value method will simply return the parameter directly, and the into_sol method will directly return self.