Module error

Module error 

Error types.

Structs

ReachMaxIteration
Error indicating that the solver reached the maximum iteration.
TimeOut
Error indicating that the solver timed out before completing.