IterState

Derive Macro IterState 

#[derive(IterState)]
A derive macro that automatically derives the IterState trait for structs that satisfy the Clone trait.

When using this macro to implement the trait, the associated types Value and Solution will both be set to Self, the init_from_value method will simply return the parameter directly, and the to_sol method will directly clone self and return it.